<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" exclude-result-prefixes="#all" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:utr="http://www.xbrl.org/2009/utr" xmlns:math="http://www.w3.org/1998/Math/MathML" xmlns:conf="http://edgar/2009/conformance" xmlns="http://www.xbrl.org/2003/instance">
  <xsl:output method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all" xmlns=""/>
  <xsl:param name="schema">edgar</xsl:param>
  <xsl:param name="year">2010</xsl:param>
  <xsl:param name="testcase">605-35-numeric-units-testcase</xsl:param>
  <xsl:param name="date">2014-02-20</xsl:param>
  <xsl:variable name="sp" select="' '"/>
  <xsl:variable name="nl" select="'&#xA;'"/>
  <xsl:variable name="us" select="'_'"/>
  <xsl:variable name="sl" select="'/'"/>
  <xsl:variable name="co" select="':'"/>
  <xsl:variable name="nsXbrli">http://www.xbrl.org/2003/instance</xsl:variable>
  <xsl:variable name="nsLink">http://www.xbrl.org/2003/linkbase</xsl:variable>
  <xsl:variable name="nsXlink">http://www.w3.org/1999/xlink</xsl:variable>
  <xsl:variable name="nsConformance">http://edgar/2009/conformance</xsl:variable>
  <xsl:variable name="prefix">edgar</xsl:variable>
  <xsl:variable name="nsTarget">
    <xsl:value-of select="concat('http://edgar/','2010','1231')"/>
  </xsl:variable>
  <xsl:variable name="nsIso">http://www.xbrl.org/2003/iso4217</xsl:variable>
  <xsl:variable name="nsDei">http://xbrl.sec.gov/dei/2014-01-31</xsl:variable>
  <xsl:variable name="good" select="concat('e60535','000','gd','-',$year,'1231')"/>
  <xsl:template match="xs:schema">
    <xsl:result-document href="{$schema}-{$year}1231.xsd" method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all">
      <xsl:apply-templates select="." mode="clean"/>
    </xsl:result-document>
    <xsl:result-document href="{$schema}-{$year}1231_lab.xml" method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all">
      <xsl:copy-of select="doc(concat('tmp/',$schema,'-',$year,'1231_lab.xml'))"/>
    </xsl:result-document>
    <xsl:result-document href="{$schema}-{$year}1231_pre.xml" method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all">
      <xsl:copy-of select="doc(concat('tmp/',$schema,'-',$year,'1231_pre.xml'))"/>
    </xsl:result-document>

    <xsl:result-document href="{$testcase}.xml" method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all">
      <xsl:processing-instruction name="xml-stylesheet">type="text/xsl" href="../../../lib/test.xsl"</xsl:processing-instruction>

      <conf:testcase xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:conf="http://edgar/2009/conformance" xsi:schemaLocation="http://edgar/2009/conformance ../../../lib/test.xsd">
        <conf:creator>
          <conf:name>SEC Office of Structured Disclosure</conf:name>
          <conf:email>StructuredData@sec.gov</conf:email>
        </conf:creator>
        <conf:number>605-35</conf:number>
        <conf:name>EDGAR Filer Manual v27 6.5.35 page 6-16</conf:name>
        <conf:description>
          <h2>If element "UTR" in a standard namespace is declared in the DTS of an instance, then the value of each 'unitRef' attribute on each fact of a type in that registry must refer to a unit declaration consistent with the data type of that fact, where consistency is defined by that registry.</h2>
          <p>XBRL 2.1 already enforces the requirement that a fact of type xbrli:monetaryItemType must have a unitRef whose xbrli:measure is an ISO standard currency. A standard numeric data type registry is similar but broader: it has a schema with numeric type declarations, and each numeric data type is associated with consistent unit declaration measures, numerators and denominators.</p>
          <p>A portion of a registry is shown below; additional information is at <a href="http://www.sec.gov/info/edgar/edgartaxonomies.shtml">http://www.sec.gov/edgar/info/edgartaxonomies.shtml</a>.</p>
          <table style="font-family: Arial; font-size: smaller; cell-spacing:0pt; border:solid black 1pt">
            <tr>
              <th>Type name-space</th>
              <th>Type element name</th>
              <th>Unit measure name-space</th>
              <th>Unit measure element names</th>
              <th>Meaning</th>
              <th>Unit numerator name-space</th>
              <th>Unit numerator element name</th>
              <th>Unit denominator namespace</th>
              <th>Unit denominator element name</th>
            </tr>
            <tr valign="top">
              <td>(any)</td>
              <td>percentItemType</td>
              <td>xbrli</td>
              <td>pure</td>
              <td>&#160;</td>
              <td>n/a</td>
              <td>disallowed</td>
              <td>n/a</td>
              <td>disallowed</td>
            </tr>
            <tr valign="top">
              <td>(any)</td>
              <td>perShareItemType</td>
              <td>n/a</td>
              <td>disallowed</td>
              <td>&#160;</td>
              <td>iso4217</td>
              <td>
                <span style="white-space: nowrap;">3-letter ISO</span> 4217 codes</td>
              <td>xbrli</td>
              <td>shares</td>
            </tr>
            <tr valign="top">
              <td rowspan="7" valign="top">(any)</td>
              <td rowspan="7" valign="top">areaItemType</td>
              <td rowspan="7" valign="top">(any)</td>
              <td>sqft</td>
              <td>Square Foot</td>
              <td rowspan="7" valign="top">n/a</td>
              <td rowspan="7" valign="top">disallowed</td>
              <td rowspan="7" valign="top">n/a</td>
              <td rowspan="7" valign="top">disallowed</td>
            </tr>
            <tr valign="top">
              <td>sqyd</td>
              <td>Square Yard</td>
            </tr>
            <tr valign="top">
              <td>sqmi</td>
              <td>Square Mile</td>
            </tr>
            <tr valign="top">
              <td>A</td>
              <td>Acre</td>
            </tr>
            <tr valign="top">
              <td>sqm</td>
              <td style="white-space: nowrap">Square Meter</td>
            </tr>
            <tr valign="top">
              <td>sqkm</td>
              <td>Square Km</td>
            </tr>
            <tr valign="top">
              <td>sqemi</td>
              <td>Square English Mile</td>
            </tr>
            <tr valign="top">
              <td rowspan="10" valign="top">(any)</td>
              <td rowspan="10" valign="top">volumeItemType</td>
              <td rowspan="10" valign="top">(any)</td>
              <td>l</td>
              <td>Liter</td>
              <td rowspan="10" valign="top">n/a</td>
              <td rowspan="10" valign="top">disallowed</td>
              <td rowspan="10" valign="top">n/a</td>
              <td rowspan="10" valign="top">disallowed</td>
            </tr>
            <tr valign="top">
              <td>m3</td>
              <td>Cubic Meter</td>
            </tr>
            <tr valign="top">
              <td>ft3</td>
              <td>Cubic Foot</td>
            </tr>
            <tr valign="top">
              <td>gal</td>
              <td>Gallon</td>
            </tr>
            <tr valign="top">
              <td>cf</td>
              <td>Cubic Feet of Natural Gas at 14.73psi and 60 degrees F</td>
            </tr>
            <tr valign="top">
              <td>Mcf</td>
              <td>Thousands of Cubic Feet of Natural Gas at 14.73psi and 60 degrees F</td>
            </tr>
            <tr valign="top">
              <td>MMcf</td>
              <td>Millions of Cubic Feet of Natural Gas at 14.73psi and 60 degrees F</td>
            </tr>
            <tr valign="top">
              <td>bbl</td>
              <td>Barrels of Oil at 60 degrees F</td>
            </tr>
            <tr valign="top">
              <td>MBbls</td>
              <td>Thousands of Barrels of Oil at 60 degrees F</td>
            </tr>
            <tr valign="top">
              <td>MMbbls</td>
              <td>Millions of Barrels of Oil at 60 degrees F</td>
            </tr>
          </table>
          <p>In this table, for example, facts whose type is based on areaItemType must have a unit whose measure is one of sqft, sqyd, sqmi, etc. The notation "(any)" means that the element namespace is ignored for the purposes of checking for consistency.</p>
          <p>REMARK: International types declared at www.xbrl.org can appear in the same DTS with US data types.</p>
          <p>REMARK: The example values in the table above may not be completely consistent with any specific Unit Types Registry.</p>
          <p>REMARK: The triggering condition of "element UTR present in a standard namespace" is present in the DEI 2012 taxonomy, but not in any prior version of DEI.</p>
        </conf:description>
        <conf:variation id="_000gd">
          <conf:name>6.5.35, Instance with all compatible combinations of numeric type and unit on directly typed concepts, GOOD.</conf:name>
          <conf:description>Instance with all compatible combinations of numeric type and unit on directly typed concepts, GOOD.</conf:description>
          <conf:data>
            <conf:instance readMeFirst="true"><xsl:value-of select="$good"/>.xml</conf:instance>
            <conf:linkbase><xsl:value-of select="concat($schema,'-',$year,'1231')"/>_pre.xml</conf:linkbase>
            <conf:linkbase><xsl:value-of select="concat($schema,'-',$year,'1231')"/>_lab.xml</conf:linkbase>
            <conf:schema><xsl:value-of select="concat($schema,'-',$year,'1231')"/>.xsd</conf:schema>
          </conf:data>
          <conf:result/>
        </conf:variation>
        <xsl:for-each select="xs:element/xs:annotation/xs:documentation[@source='nogood']/*">
          <xsl:variable name="element" select="ancestor::xs:element/@name"/>
          <xsl:variable name="unit" select="."/>
          <xsl:variable name="seq" select="format-number(position()+1,'000')"/>
          <xsl:variable name="id" select="concat($us,$seq,'ng')"/>
          <xsl:variable name="base" select="concat('e60535',$seq,'ng','-','2010','1231')"/>
          <xsl:variable name="pretty" select="concat($element,' fact with '
              ,(if (contains(@id,'__x')) then
                concat('locally defined unit ',substring-after(@id,'__x'))
                else
                concat('unit ',substring-after(@id,'__'))),
                ', NOGOOD')"/>
          <conf:variation id="{$id}">
            <conf:name>
              <xsl:text>6.5.35, </xsl:text>
              <xsl:value-of select="$pretty"/>
            </conf:name>
            <conf:description>
              <xsl:value-of select="$pretty"/>
            </conf:description>
            <conf:data>
              <conf:instance readMeFirst="true"><xsl:value-of select="$base"/>.xml</conf:instance>
              <conf:linkbase><xsl:value-of select="concat($schema,'-',$year,'1231')"/>_pre.xml</conf:linkbase>
              <conf:linkbase><xsl:value-of select="concat($schema,'-',$year,'1231')"/>_lab.xml</conf:linkbase>
              <conf:schema><xsl:value-of select="concat($schema,'-',$year,'1231')"/>.xsd</conf:schema>
            </conf:data>
            <conf:result>
              <conf:assert severity="err" num="60535" name="Incompatible-Numeric-Type-And-Unit" frd="cp"/>
            </conf:result>
          </conf:variation>
        </xsl:for-each>
        <conf:variation id="_998gd">
          <conf:name>6.5.35, Element UTR is not declared, and Type num:energyItemType (Base xbrli:decimalItemType) with edgar:unit1, GOOD.</conf:name>
          <conf:description>Element UTR is not declared (in dei 2009), and Type num:energyItemType (Base xbrli:decimalItemType) with edgar:unit1, so it is still GOOD.</conf:description>
          <xsl:call-template name="variation_data">
            <xsl:with-param name="base">998gd</xsl:with-param>
          </xsl:call-template>
          <conf:result/>
        </conf:variation>
        <conf:variation id="_999gd">
          <conf:name>6.5.35, Element UTR is not declared, and monetaryItemType with unit iso4217:EEK, GOOD.</conf:name>
          <conf:description>Element UTR is not declared (in dei 2009), and monetaryItemType with unit iso4217:EEK (EEK is no longer a valid currency), but without the UTR element, it is GOOD.</conf:description>
          <xsl:call-template name="variation_data">
            <xsl:with-param name="base">999gd</xsl:with-param>
          </xsl:call-template>
          <conf:result/>
        </conf:variation>
      </conf:testcase>
    </xsl:result-document>
    <xsl:result-document href="{$good}.xml" method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all">
      <xsl:element name="xbrl" namespace="{$nsXbrli}">
        <xsl:call-template name="prologue"/>
        <xsl:for-each-group select="xs:element/xs:annotation/xs:documentation[@source='good']/*" group-by="substring-after(@id,'__')">
          <xsl:element name="unit">
            <xsl:attribute name="id" select="current-grouping-key()"/>
            <xsl:copy-of select="*" copy-namespaces="no"/>
          </xsl:element>
        </xsl:for-each-group>
        <xsl:for-each select="xs:element">
          <xsl:variable name="element" select="@name"/>
          <xsl:for-each select="xs:annotation/xs:documentation[@source='good']/*">
            <xsl:element name="{$prefix}:{$element}" namespace="{$nsTarget}">
              <xsl:attribute name="unitRef" select="substring-after(@id,'__')"/>
              <xsl:attribute name="contextRef">_</xsl:attribute>
              <xsl:attribute name="nil" namespace="http://www.w3.org/2001/XMLSchema-instance">true</xsl:attribute>
            </xsl:element>
            <xsl:element name="{$prefix}:Derived{$element}" namespace="{$nsTarget}">
              <xsl:attribute name="unitRef" select="substring-after(@id,'__')"/>
              <xsl:attribute name="contextRef">_</xsl:attribute>
              <xsl:attribute name="nil" namespace="http://www.w3.org/2001/XMLSchema-instance">true</xsl:attribute>
            </xsl:element>
          </xsl:for-each>
        </xsl:for-each>
      </xsl:element>
    </xsl:result-document>
    <xsl:for-each select="xs:element/xs:annotation/xs:documentation[@source='nogood']/*">
      <xsl:variable name="seq" select="format-number(position()+1,'000')"/>
      <xsl:variable name="id" select="concat($us,$seq,'ng')"/>
      <xsl:variable name="base" select="concat('e60535',$seq,'ng-',concat('2010','1231'))"/>
      <xsl:variable name="nogood" select="concat($base,'.xml')"/>
      <xsl:result-document href="{$nogood}" method="xml" encoding="UTF-8" indent="yes" exclude-result-prefixes="#all">
        <xsl:element name="xbrl" namespace="{$nsXbrli}">
          <xsl:call-template name="prologue"/>
          <xsl:element name="unit">
            <xsl:attribute name="id" select="substring-after(@id,'__')"/>
            <xsl:copy-of select="*" copy-namespaces="no"/>
          </xsl:element>
          <xsl:element name="{$prefix}:{ancestor::xs:element/@name}" namespace="{$nsTarget}">
            <xsl:attribute name="unitRef" select="substring-after(@id,'__')"/>
            <xsl:attribute name="contextRef">_</xsl:attribute>
            <xsl:attribute name="nil" namespace="http://www.w3.org/2001/XMLSchema-instance">true</xsl:attribute>
          </xsl:element>
        </xsl:element>
      </xsl:result-document>
    </xsl:for-each>
    <xsl:call-template name="instance_998gd"/>
    <xsl:call-template name="schema">
      <xsl:with-param name="base">998gd</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="label_linkbase">
      <xsl:with-param name="base">998gd</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="presentation_linkbase">
      <xsl:with-param name="base">998gd</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="instance_999gd"/>
    <xsl:call-template name="schema">
      <xsl:with-param name="base">999gd</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="label_linkbase">
      <xsl:with-param name="base">999gd</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="presentation_linkbase">
      <xsl:with-param name="base">999gd</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  <xsl:template name="prologue">
    <xsl:namespace name="" select="$nsXbrli"/>
    <xsl:namespace name="xbrli" select="$nsXbrli"/>
    <xsl:namespace name="link" select="$nsLink"/>
    <xsl:namespace name="xlink" select="$nsXlink"/>
    <xsl:namespace name="{$prefix}" select="$nsTarget"/>
    <xsl:namespace name="iso" select="$nsIso"/>
    <xsl:namespace name="utr">http://www.xbrl.org/2009/utr</xsl:namespace>
    <xsl:namespace name="xsi">http://www.w3.org/2001/XMLSchema-instance</xsl:namespace>
    <xsl:namespace name="local">local</xsl:namespace>
    <xsl:namespace name="dei" select="$nsDei"/>
    <link:schemaRef xlink:type="simple" xlink:href="{$schema}-{$year}1231.xsd"/>
    <context id="_">
      <entity>
        <identifier scheme="http://www.sec.gov/CIK">9876543210</identifier>
      </entity>
      <period>
        <startDate>
          <xsl:value-of select="concat('2010','-01-31')"/>
        </startDate>
        <endDate>
          <xsl:value-of select="concat('2010','-12-31')"/>
        </endDate>
      </period>
    </context>
    <xsl:element name="DocumentType" namespace="{$nsDei}"><xsl:attribute name="contextRef">_</xsl:attribute>8-K</xsl:element>
    <xsl:element name="AmendmentFlag" namespace="{$nsDei}"><xsl:attribute name="contextRef">_</xsl:attribute>false</xsl:element>
    <xsl:element name="EntityRegistrantName" namespace="{$nsDei}">
      <xsl:attribute name="contextRef">_</xsl:attribute>
      <xsl:value-of select="concat('ng_',ancestor::xs:element/@name,$us,substring-after(@id,'__'))"/>
    </xsl:element>
    <xsl:element name="EntityCentralIndexKey" namespace="{$nsDei}"><xsl:attribute name="contextRef">_</xsl:attribute>9876543210</xsl:element>
    <xsl:element name="DocumentPeriodEndDate" namespace="{$nsDei}">
      <xsl:attribute name="contextRef">_</xsl:attribute>
      <xsl:value-of select="concat('2010','-12-31')"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="xs:annotation[parent::xs:element]" mode="clean"/>
  <xsl:template match="xs:annotation[parent::xs:schema]" mode="clean">
    <xsl:copy>
      <xsl:copy-of select="xs:appinfo"/>
    </xsl:copy>
  </xsl:template>
  <xsl:template match="xs:*" mode="clean">
    <xsl:copy>
      <xsl:apply-templates select="@*" mode="clean"/>
      <xsl:apply-templates select="*" mode="clean"/>
    </xsl:copy>
  </xsl:template>
  <xsl:template match="@*" mode="clean">
    <xsl:copy-of select="."/>
  </xsl:template>
  <xsl:template name="variation_data">
    <xsl:param name="base">998gd</xsl:param>
    <conf:data>
      <conf:instance readMeFirst="true">
        <xsl:value-of select="concat('e60535',$base,'-20101231.xml')"/>
      </conf:instance>
      <conf:linkbase>
        <xsl:value-of select="concat('e60535',$base,'-20101231_lab.xml')"/>
      </conf:linkbase>
      <conf:linkbase>
        <xsl:value-of select="concat('e60535',$base,'-20101231_pre.xml')"/>
      </conf:linkbase>
      <conf:schema>
        <xsl:value-of select="concat('e60535',$base,'-20101231.xsd')"/>
      </conf:schema>
    </conf:data>
  </xsl:template>
  <xsl:template name="label_linkbase">
    <xsl:param name="base">998gd</xsl:param>
    <xsl:result-document href="e60535{$base}-20101231_lab.xml" encoding="UTF-8" indent="yes" method="xml">
      <link:linkbase xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.xbrl.org/2003/linkbase http://www.xbrl.org/2003/xbrl-linkbase-2003-12-31.xsd" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:xlink="http://www.w3.org/1999/xlink">
        <link:labelLink xlink:type="extended" xlink:role="http://www.xbrl.org/2003/role/link">
          <link:loc xlink:type="locator" xlink:href="e60535{$base}-20101231.xsd#e60535_Top" xlink:label="Top"/>
          <link:loc xlink:type="locator" xlink:href="e60535{$base}-20101231.xsd#e60535_EnergyConcept" xlink:label="EnergyConcept"/>
          <link:loc xlink:type="locator" xlink:href="e60535{$base}-20101231.xsd#e60535_MonetaryConcept" xlink:label="MonetaryConcept"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_AmendmentFlag" xlink:label="AmendmentFlag"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_DocumentPeriodEndDate" xlink:label="DocumentPeriodEndDate"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_DocumentType" xlink:label="DocumentType"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_EntityCentralIndexKey" xlink:label="EntityCentralIndexKey"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_EntityRegistrantName" xlink:label="EntityRegistrantName"/>
          <link:label xlink:type="resource" xlink:label="label_Top" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US" id="label_Top">Top</link:label>
          <link:label xlink:type="resource" xlink:label="label_MonetaryConcept" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US" id="label_MonetaryConcept">Monetary Concept</link:label>
          <link:label xlink:type="resource" xlink:label="label_EnergyConcept" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US" id="label_EnergyConcept">Energy Concept</link:label>
          <link:label xlink:type="resource" xlink:label="label_AmendmentFlag" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US">Amendment Flag</link:label>
          <link:label xlink:type="resource" xlink:label="label_DocumentPeriodEndDate" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US">Document Period End Date</link:label>
          <link:label xlink:type="resource" xlink:label="label_DocumentType" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US">Document Type</link:label>
          <link:label xlink:type="resource" xlink:label="label_EntityCentralIndexKey" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US">Entity Central Index Key</link:label>
          <link:label xlink:type="resource" xlink:label="label_EntityRegistrantName" xlink:role="http://www.xbrl.org/2003/role/label" xml:lang="en-US">Entity Registrant Name</link:label>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="Top" xlink:to="label_Top"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="EnergyConcept" xlink:to="label_EnergyConcept"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="MonetaryConcept" xlink:to="label_MonetaryConcept"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="AmendmentFlag" xlink:to="label_AmendmentFlag"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="DocumentPeriodEndDate" xlink:to="label_DocumentPeriodEndDate"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="DocumentType" xlink:to="label_DocumentType"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="EntityCentralIndexKey" xlink:to="label_EntityCentralIndexKey"/>
          <link:labelArc xlink:type="arc" xlink:arcrole="http://www.xbrl.org/2003/arcrole/concept-label" xlink:from="EntityRegistrantName" xlink:to="label_EntityRegistrantName"/>
        </link:labelLink>
      </link:linkbase>
    </xsl:result-document>
  </xsl:template>
  <xsl:template name="presentation_linkbase">
    <xsl:param name="base">998gd</xsl:param>
    <xsl:result-document href="e60535{$base}-20101231_pre.xml" encoding="UTF-8" indent="yes" method="xml">
      <link:linkbase xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.xbrl.org/2003/linkbase http://www.xbrl.org/2003/xbrl-linkbase-2003-12-31.xsd" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:xlink="http://www.w3.org/1999/xlink">
        <link:presentationLink xlink:type="extended" xlink:role="http://www.xbrl.org/2003/role/link">
          <link:loc xlink:type="locator" xlink:href="e60535{$base}-20101231.xsd#e60535_Top" xlink:label="Top"/>
          <link:loc xlink:type="locator" xlink:href="e60535{$base}-20101231.xsd#e60535_EnergyConcept" xlink:label="EnergyConcept"/>
          <link:loc xlink:type="locator" xlink:href="e60535{$base}-20101231.xsd#e60535_MonetaryConcept" xlink:label="MonetaryConcept"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_AmendmentFlag" xlink:label="AmendmentFlag"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_DocumentPeriodEndDate" xlink:label="DocumentPeriodEndDate"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_DocumentType" xlink:label="DocumentType"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_EntityCentralIndexKey" xlink:label="EntityCentralIndexKey"/>
          <link:loc xlink:type="locator" xlink:href="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd#dei_EntityRegistrantName" xlink:label="EntityRegistrantName"/>
          <link:presentationArc xlink:type="arc" order="1" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="EnergyConcept"/>
          <link:presentationArc xlink:type="arc" order="2" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="MonetaryConcept"/>
          <link:presentationArc xlink:type="arc" order="3" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="AmendmentFlag"/>
          <link:presentationArc xlink:type="arc" order="4" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="DocumentPeriodEndDate"/>
          <link:presentationArc xlink:type="arc" order="5" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="DocumentType"/>
          <link:presentationArc xlink:type="arc" order="6" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="EntityCentralIndexKey"/>
          <link:presentationArc xlink:type="arc" order="7" xlink:arcrole="http://www.xbrl.org/2003/arcrole/parent-child" xlink:from="Top" xlink:to="EntityRegistrantName"/>
        </link:presentationLink>
      </link:linkbase>
    </xsl:result-document>
  </xsl:template>
  <xsl:template name="schema">
    <xsl:param name="base">998gd</xsl:param>
    <xsl:result-document href="e60535{$base}-20101231.xsd" encoding="UTF-8" indent="yes" method="xml">
      <xs:schema targetNamespace="http://e60535/20101231" elementFormDefault="qualified" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:e60535="http://e60535/20101231" xmlns:dei="http://xbrl.us/dei/2009-01-31" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:num="http://www.xbrl.org/dtr/type/numeric" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xbrli="http://www.xbrl.org/2003/instance" xmlns:xlink="http://www.w3.org/1999/xlink">
        <xs:annotation>
          <xs:appinfo>
            <link:linkbaseRef xlink:type="simple" xlink:href="e60535{$base}-20101231_pre.xml" xlink:role="http://www.xbrl.org/2003/role/presentationLinkbaseRef" xlink:arcrole="http://www.w3.org/1999/xlink/properties/linkbase"/>
            <link:linkbaseRef xlink:type="simple" xlink:href="e60535{$base}-20101231_lab.xml" xlink:role="http://www.xbrl.org/2003/role/labelLinkbaseRef" xlink:arcrole="http://www.w3.org/1999/xlink/properties/linkbase"/>
            <link:roleType roleURI="http://e60535/role/EntityInformation" id="EntityInformation">
              <link:definition>991 - Document - Entity Information</link:definition>
              <link:usedOn>link:presentationLink</link:usedOn>
              <link:usedOn>link:calculationLink</link:usedOn>
              <link:usedOn>link:definitionLink</link:usedOn>
            </link:roleType>
            <link:roleType roleURI="http://e60535/role/DocumentInformation" id="DocumentInformation">
              <link:definition>992 - Document - Document Information</link:definition>
              <link:usedOn>link:presentationLink</link:usedOn>
              <link:usedOn>link:calculationLink</link:usedOn>
              <link:usedOn>link:definitionLink</link:usedOn>
            </link:roleType>
            <link:roleType roleURI="http://e60535/role/OtherInformation" id="OtherInformation">
              <link:definition>990 - Document - Other Information</link:definition>
              <link:usedOn>link:presentationLink</link:usedOn>
              <link:usedOn>link:calculationLink</link:usedOn>
              <link:usedOn>link:definitionLink</link:usedOn>
            </link:roleType>
            <link:roleType roleURI="http://e60535/role/Defaults" id="Defaults">
              <link:definition>999 - Document - Defaults</link:definition>
              <link:usedOn>link:presentationLink</link:usedOn>
              <link:usedOn>link:calculationLink</link:usedOn>
              <link:usedOn>link:definitionLink</link:usedOn>
            </link:roleType>
          </xs:appinfo>
        </xs:annotation>
        <xs:import namespace="http://www.xbrl.org/2003/instance" schemaLocation="http://www.xbrl.org/2003/xbrl-instance-2003-12-31.xsd"/>
        <xs:import namespace="http://xbrl.org/2005/xbrldt" schemaLocation="http://www.xbrl.org/2005/xbrldt-2005.xsd"/>
        <xs:import namespace="http://xbrl.us/dei/2009-01-31" schemaLocation="http://taxonomies.xbrl.us/us-gaap/2009/non-gaap/dei-2009-01-31.xsd"/>
        <xs:import namespace="http://www.xbrl.org/dtr/type/numeric" schemaLocation="http://www.xbrl.org/dtr/type/numeric-2009-12-16.xsd"/>
        <xs:element name="Top" id="e60535_Top" type="xbrli:stringItemType" substitutionGroup="xbrli:item" abstract="true" nillable="true" xbrli:periodType="duration"/>
        <xs:element name="EnergyConcept" id="e60535_EnergyConcept" type="num:energyItemType" substitutionGroup="xbrli:item" abstract="false" nillable="true" xbrli:periodType="duration"/>
        <xs:element name="MonetaryConcept" id="e60535_MonetaryConcept" type="xbrli:monetaryItemType" substitutionGroup="xbrli:item" abstract="false" nillable="true" xbrli:periodType="duration"/>
      </xs:schema>
    </xsl:result-document>
  </xsl:template>
  <xsl:template name="instance_998gd">
    <xsl:param name="base">998gd</xsl:param>
    <xsl:result-document href="e60535{$base}-20101231.xml" encoding="UTF-8" indent="yes" method="xml">
      <xbrli:xbrl xmlns:edgar="http://e60535/20101231" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:dei="http://xbrl.us/dei/2009-01-31" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xbrli="http://www.xbrl.org/2003/instance" xmlns:xlink="http://www.w3.org/1999/xlink">
        <link:schemaRef xlink:type="simple" xlink:href="e60535{$base}-20101231.xsd"/>
        <xbrli:context id="d">
          <xbrli:entity>
            <xbrli:identifier scheme="http://www.sec.gov/CIK">9876543210</xbrli:identifier>
          </xbrli:entity>
          <xbrli:period>
            <xbrli:startDate>2010-01-01</xbrli:startDate>
            <xbrli:endDate>2010-12-31</xbrli:endDate>
          </xbrli:period>
        </xbrli:context>
        <xbrli:unit id="unit1">
          <xbrli:measure>edgar:unit1</xbrli:measure>
        </xbrli:unit>
        <edgar:EnergyConcept contextRef="d" unitRef="unit1" xsi:nil="true"/>
        <dei:DocumentType contextRef="d">8-K</dei:DocumentType>
        <dei:AmendmentFlag contextRef="d">false</dei:AmendmentFlag>
        <dei:DocumentPeriodEndDate contextRef="d">2010-12-31</dei:DocumentPeriodEndDate>
        <dei:EntityRegistrantName contextRef="d">e60535<xsl:value-of select="$base"/></dei:EntityRegistrantName>
        <dei:EntityCentralIndexKey contextRef="d">9876543210</dei:EntityCentralIndexKey>
      </xbrli:xbrl>
    </xsl:result-document>
  </xsl:template>
  <xsl:template name="instance_999gd">
    <xsl:param name="base">999gd</xsl:param>
    <xsl:result-document href="e60535{$base}-20101231.xml" encoding="UTF-8" indent="yes" method="xml">
      <xbrli:xbrl xmlns:edgar="http://e60535/20101231" xmlns:link="http://www.xbrl.org/2003/linkbase" xmlns:dei="http://xbrl.us/dei/2009-01-31" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xbrli="http://www.xbrl.org/2003/instance" xmlns:xlink="http://www.w3.org/1999/xlink">
        <link:schemaRef xlink:type="simple" xlink:href="e60535{$base}-20101231.xsd"/>
        <xbrli:context id="d">
          <xbrli:entity>
            <xbrli:identifier scheme="http://www.sec.gov/CIK">9876543210</xbrli:identifier>
          </xbrli:entity>
          <xbrli:period>
            <xbrli:startDate>2010-01-01</xbrli:startDate>
            <xbrli:endDate>2010-12-31</xbrli:endDate>
          </xbrli:period>
        </xbrli:context>
        <xbrli:unit id="EEK">
          <xbrli:measure xmlns:iso4217="http://www.xbrl.org/2003/iso4217">iso4217:EEK</xbrli:measure>
        </xbrli:unit>
        <edgar:MonetaryConcept contextRef="d" unitRef="EEK" xsi:nil="true"/>
        <dei:DocumentType contextRef="d">8-K</dei:DocumentType>
        <dei:AmendmentFlag contextRef="d">false</dei:AmendmentFlag>
        <dei:DocumentPeriodEndDate contextRef="d">2010-12-31</dei:DocumentPeriodEndDate>
        <dei:EntityRegistrantName contextRef="d">e60535<xsl:value-of select="$base"/></dei:EntityRegistrantName>
        <dei:EntityCentralIndexKey contextRef="d">9876543210</dei:EntityCentralIndexKey>
      </xbrli:xbrl>
    </xsl:result-document>
  </xsl:template>
</xsl:stylesheet>
